==> open_watcom_1.4.0-src.zip: bld/fe_misc/c/ringcarv.c <==
/****************************************************************************
*
*                            Open Watcom Project
*
*    Portions Copyright (c) 1983-2002 Sybase, Inc. All Rights Reserved.
*
*  ========================================================================
*
*    This file contains Original Code and/or Modifications of Original
*    Code as defined in and that are subject to the Sybase Open Watcom
*    Public License version 1.0 (the 'License'). You may not use this file
*    except in compliance with the License. BY USING THIS FILE YOU AGREE TO
*    ALL TERMS AND CONDITIONS OF THE LICENSE. A copy of the License is
*    provided with the Original Code and Modifications, and is also
*    available at www.sybase.com/developer/opensource.
*
*    The Original Code and all software distributed under the License are
*    distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
*    EXPRESS OR IMPLIED, AND SYBASE AND ALL CONTRIBUTORS HEREBY DISCLAIM
*    ALL SUCH WARRANTIES, INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF
*    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR
*    NON-INFRINGEMENT. Please see the License for the specific language
*    governing rights and limitations under the License.
*
*  ========================================================================
*
* Description:  WHEN YOU FIGURE OUT WHAT THIS FILE DOES, PLEASE
*               DESCRIBE IT HERE!
*
****************************************************************************/


#include "ringcarv.h"


void* RingCarveAlloc(           // CARVER ALLOC AND APPEND AN ENTRY
    carve_t carver,             // - carving control
    void **hdr )                // - addr( ring header )
{
    void *elt;

    elt = CarveAlloc( carver );
    RingAppend( hdr, elt );
    return elt;
}


void RingCarveFree(             // CARVER FREE ALL ELEMENTS IN A RING
    carve_t carver,             // - carving control
    void **hdr )                // - addr( ring header )
{
    void *elt;

    RingIterBegSafe( *hdr, elt ) {
        CarveFree( carver, elt );
    } RingIterEndSafe( elt );
    *hdr = NULL;
}

==> open_watcom_1.7.0-src.zip: bld/fe_misc/c/ringcarv.c <==
/****************************************************************************
*
*                            Open Watcom Project
*
*    Portions Copyright (c) 1983-2002 Sybase, Inc. All Rights Reserved.
*
*  ========================================================================
*
*    This file contains Original Code and/or Modifications of Original
*    Code as defined in and that are subject to the Sybase Open Watcom
*    Public License version 1.0 (the 'License'). You may not use this file
*    except in compliance with the License. BY USING THIS FILE YOU AGREE TO
*    ALL TERMS AND CONDITIONS OF THE LICENSE. A copy of the License is
*    provided with the Original Code and Modifications, and is also
*    available at www.sybase.com/developer/opensource.
*
*    The Original Code and all software distributed under the License are
*    distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
*    EXPRESS OR IMPLIED, AND SYBASE AND ALL CONTRIBUTORS HEREBY DISCLAIM
*    ALL SUCH WARRANTIES, INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF
*    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR
*    NON-INFRINGEMENT. Please see the License for the specific language
*    governing rights and limitations under the License.
*
*  ========================================================================
*
* Description:  WHEN YOU FIGURE OUT WHAT THIS FILE DOES, PLEASE
*               DESCRIBE IT HERE!
*
****************************************************************************/


#include "ringcarv.h"


void* RingCarveAlloc(           // CARVER ALLOC AND APPEND AN ENTRY
    carve_t carver,             // - carving control
    void *hdr )                 // - addr( ring header )
{
    void *elt;

    elt = CarveAlloc( carver );
    RingAppend( hdr, elt );
    return elt;
}


void RingCarveFree(             // CARVER FREE ALL ELEMENTS IN A RING
    carve_t carver,             // - carving control
    void *_hdr )                // - addr( ring header )
{
    void **hdr = _hdr;
    void *elt;

    RingIterBegSafe( *hdr, elt ) {
        CarveFree( carver, elt );
    } RingIterEndSafe( elt );
    *hdr = NULL;
}
